<!-- Feel free to remove check-list items aren't relevant to your change -->

 - [ ] Closes #xxxx
 - [ ] Tests added and passed `make coverage`
 - [ ] Passes `make lint`
 - [ ] User visible changes (including notable bug fixes) are documented in `HISTORY.rst`
 - [ ] After adding new functions/methods ran `make apidocs`
